@@ -1,11 +1,7 @@
-import six
-
-from django.utils.functional import LazyObject
-from ..lib import force_text
 from ..utils import get_singleton
 
 
-class JustInTime(object):
+class JustInTime:
     """
     A strategy that ensures the file exists right before it's needed.
 
@@ -18,7 +14,7 @@ class JustInTime(object):
         file.generate()
 
 
-class Optimistic(object):
+class Optimistic:
     """
     A strategy that acts immediately when the source file changes and assumes
     that the cache files will not be removed (i.e. it doesn't ensure the
@@ -33,14 +29,14 @@ class Optimistic(object):
         return False
 
 
-class DictStrategy(object):
+class DictStrategy:
     def __init__(self, callbacks):
         for k, v in callbacks.items():
             setattr(self, k, v)
 
 
 def load_strategy(strategy):
-    if isinstance(strategy, six.string_types):
+    if isinstance(strategy, str):
         strategy = get_singleton(strategy, 'cache file strategy')
     elif isinstance(strategy, dict):
         strategy = DictStrategy(strategy)
