@@ -1,6 +1,8 @@
-from django.db.models.fields.files import ImageFieldFile
 import os
-from ...utils import suggest_extension, generate
+
+from django.db.models.fields.files import ImageFieldFile
+
+from ...utils import generate, suggest_extension
 
 
 class ProcessedImageFieldFile(ImageFieldFile):
@@ -10,4 +12,4 @@ class ProcessedImageFieldFile(ImageFieldFile):
         ext = suggest_extension(name, spec.format)
         new_name = '%s%s' % (filename, ext)
         content = generate(spec)
-        return super(ProcessedImageFieldFile, self).save(new_name, content, save)
+        return super().save(new_name, content, save)
